
% parameters of the motor

KM = 1;     % N-m/A
KV = 1;     % V/rad/sec
R = 10;     % ohm
L = .01;    % H
J = .1;     % N-m/rad/s^2
B = 0.28;   % N-m/(rad/sec)




% integrator gain

K = 100;

% time interval of the simulation 
%  NOTE: may need to adjust this parameter
tfinal = 10;  


% call SIMULINK to perform simulation
sim('DC_motor_PS4');


figure(1)
clf


plot(tout,yout(:,1),'-',tout,yout(:,2),'--')
legend('speed','torque')
%xlabel('time, seconds')
title(['step response, K = ',num2str(K)])
h = gca;
ylimits = get(h,'YLim');
set(h,'YTick',ylimits(1):.1:ylimits(2))
grid


% transfer function of feedback system
[num,den] = linmod('DC_motor_PS4');
 

% plot frequency response 

omega = logspace(-2,2);

[mag,phase] = bode(num,den,omega);


figure(2)
clf
 subplot(2,1,1)
semilogx(omega,20*log10(mag(:,1)),'-',omega,20*log10(mag(:,2)),'--')
ylabel('magnitude, db')
title(['frequency response, K = ',num2str(K)])
legend('speed','torque')
 subplot(2,1,2)
semilogx(omega,phase(:,1),'-',omega,phase(:,2),'--')
xlabel('frequency, rad/sec')
ylabel('phase, degrees')


% characteristic roots
format short e
char_roots = roots(den)
% the characteristic polynomial will have three roots
% the following formula will work if you input the complex root 
% that has positive imaginary part
% you shoould check to see that this is the second root returned
% as in the example
wn = abs(char_roots(2));
zeta = -real(char_roots(2))/wn;


% note that the axes on this plot are set so that it only displays 
% the two roots closest to the origin. The root associated with the time constant
% of the electrical subsystem is very fast
figure(3)
clf

plot(real(char_roots),imag(char_roots),'d')
axis('equal')
axis([-10 10 -10 10])
sgrid([0:.1:1],[0:1:10])

if abs(zeta) < 1
    title([' \zeta = ',num2str(zeta),', \omega_n = ',num2str(wn)])
else
    title('real roots')
end


figure(4)
clf

 subplot(2,2,1)
 
 plot(tout,yout(:,1),'-',tout,yout(:,2),'--')
legend('speed','torque')
%xlabel('time, seconds')
title(['step response, K = ',num2str(K)])

 subplot(2,2,2)
 
 
 semilogx(omega,20*log10(mag(:,1)),'-',omega,20*log10(mag(:,2)),'--')
ylabel('magnitude, db')
title(['frequency response, K = ',num2str(K)])
legend('speed','torque',4)
 


subplot(2,2,3)

plot(real(char_roots),imag(char_roots),'d')
axis('equal')
axis([-10 10 -10 10])
sgrid([0:.1:1],[0:1:10])

if abs(zeta) < 1
    title([' \zeta = ',num2str(zeta),', \omega_n = ',num2str(wn)])
else
    title('real roots')
end

subplot(2,2,4)

semilogx(omega,phase(:,1),'-',omega,phase(:,2),'--')
xlabel('frequency, rad/sec')
ylabel('phase, degrees')